@@ -4,9 +4,9 @@
 #' @param init a named \code{\link{vector}} of length 8, with point estimates of model parameters (see details).
 #' @param time time sequence for which output is wanted; the first value of times must be the initial time.
 #' @param s.range optional sequence (between 0 and 1) of the sterilization rates to be simulated.
-#' @param ab.range optional \code{\link{vector}} of length 2, with range (ie, confidence interval) of abandonment rates to be assessed. If given, the rates evaluated are those specified by the argument plus the point estimate given in \code{pars}.
-#' @param ad.range optional \code{\link{vector}} of length 2, with range (ie, confidence interval) of adoption rates to be assessed. If given, the rates evaluated are those specified by the argument plus the point estimate given in \code{pars}.
-#' @param im.range optional \code{\link{vector}} of length 2, with range of values of immigration rates to be assessed. This must be expressed as a percentage of owned animals carrying capacity.
+#' @param a.range optional \code{\link{vector}} of length 2, with range (ie, confidence interval) of abandonment rates to be assessed. If given, the rates evaluated are those specified by the argument plus the point estimate given in \code{pars}.
+#' @param alpha.range optional \code{\link{vector}} of length 2, with range (ie, confidence interval) of adoption rates to be assessed. If given, the rates evaluated are those specified by the argument plus the point estimate given in \code{pars}.
+#' @param v.range optional \code{\link{vector}} of length 2, with range of values of immigration rates to be assessed. This must be expressed as a percentage of owned animals carrying capacity.
 #' @param s.fm logical. If \code{TRUE}, s.range is used for females and males and if \code{FALSE}, it is only used for females (for males, the point estimate given in \code{pars} is used.)
 #' @param ... further arguments passed to \link[deSolve]{ode} function.
 #' @details The \code{pars} argument must contain named values, using the following conventions: \code{1}: owned animals; \code{2}: stray animals; \code{f}: females; \code{m}: males. Then:
@@ -22,9 +22,9 @@
 #' 
 #' \code{h1} and \code{h2}: mean harem size.
 #' 
-#' \code{ab}: abandonment rate.
+#' \code{a}: abandonment rate.
 #' 
-#' \code{ad}: adoption rate.
+#' \code{alpha}: adoption rate.
 #' 
 #' \code{v}: immigration rate.
 #' 
@@ -34,7 +34,7 @@
 #' 
 #' \code{f1}, \code{fs1}, \code{m1}, \code{ms1}, \code{f2}, \code{fs2}, \code{m2} and \code{ms2}.
 #' 
-#' If any range is specified (e.g \code{s.range}), the remaining ranges must be specified too (\code{ab.range}, \code{ad.range} and \code{im.range}).
+#' If any range is specified (e.g \code{s.range}), the remaining ranges must be specified too (\code{a.range}, \code{alpha.range} and \code{v.range}).
 #' The function is a wrapper around the defaults of \link[deSolve]{ode} function, whose help page must be consulted for details. An exception is the method argument, which here has "rk4" as a default.
 #' @return \code{\link{list}}. The first element, \code{name}, is a string with the name of the function, the second element, \code{model}, is the model function. The third, fourth and fifth elements are vectors (\code{pars}, \code{init}, \code{time}, respectively) containing the \code{pars}, \code{init} and \code{time} arguments of the function. The sisxthth element \code{results} is a \code{\link{data.frame}} with up to as many rows as elements in time. The first column contain the time and subsequent columns contain the size of specific subpopulations, named according to conventions above. The \code{group} column differentiate between owned and strays. When *.range arguments are given, the last fourth columsn specify their instances.
 #' @note Logistic growth models are not intended for scenarios in which
@@ -49,7 +49,7 @@
 #'    df1 = 0.104, dm1 = 0.098, df2 = 0.125, dm2 = 0.118,
 #'    sf1 = 0.069, sf2 = 0.05, sm1 = 0.028, sm2 = 0.05,
 #'    k1 = 98050, k2 = 8055, h1 = 1, h2 = 0.5,
-#'    ab = 0.054, ad = 0.1, v = 0.2, z = 0.1)
+#'    a = 0.054, alpha = 0.1, v = 0.2, z = 0.1)
 #'    
 #' init.solve.iasa = c(
 #'    f1 = 33425, fs1 = 10865,
@@ -68,17 +68,17 @@
 #'                           init = init.solve.iasa, 
 #'                           time = 0:8,
 #'                           s.range = seq(0, .4, l = 15), 
-#'                           ab.range = c(0, .2), 
-#'                           ad.range = c(0, .2),
-#'                           im.range = c(0, .1),
+#'                           a.range = c(0, .2), 
+#'                           alpha.range = c(0, .2),
+#'                           v.range = c(0, .1),
 #'                           method = 'rk4')
 #'
-SolveIASA <- function(pars = NULL, init = NULL, time = NULL, s.range = NULL, ab.range = NULL, ad.range = NULL, im.range = NULL, s.fm = TRUE, ...) {
+SolveIASA <- function(pars = NULL, init = NULL, time = NULL, s.range = NULL, a.range = NULL, alpha.range = NULL, v.range = NULL, s.fm = TRUE, ...) {
   if(!setequal(names(pars), c('b1', 'b2', 'df1', 'dm1', 
                               'df2', 'dm2', 'sf1', 'sf2', 
                               'sm1', 'sm2', 'k1', 'k2', 'h1',
-                              'h2', 'ab', 'ad', 'v', 'z'))) {
-    stop('Values in pars must have the following names:\nb1, b2, df1, dm1, df2, dm2, sf1, sf2, sm1, sm2, k1, k2, h1, h2, ab, ad, v, z')
+                              'h2', 'a', 'alpha', 'v', 'z'))) {
+    stop('Values in pars must have the following names:\nb1, b2, df1, dm1, df2, dm2, sf1, sf2, sm1, sm2, k1, k2, h1, h2, a, alpha, v, z')
   }
   if(!setequal(names(init), c('f1', 'fs1', 'm1', 'ms1',
                               'f2', 'fs2', 'm2', 'ms2'))) {
@@ -115,40 +115,40 @@ SolveIASA <- function(pars = NULL, init = NULL, time = NULL, s.range = NULL, ab.
         q <- k1 * v * (1 - z) / 2
         qs <- k1 * v * z / 2
         
-        d.f1 <- (w.f1 - c.f1 - sf1 - ab) * f1 +
-          (ad * f2 + q) * (1 - (omega1 / k1))
+        d.f1 <- (w.f1 - c.f1 - sf1 - a) * f1 +
+          (alpha * f2 + q) * (1 - (omega1 / k1))
         
-        d.fs1 <- - (c.f1 + ab) * fs1 + sf1 * f1 + 
-          (ad * fs2 + qs) * (1 - (omega1 / k1))
+        d.fs1 <- - (c.f1 + a) * fs1 + sf1 * f1 + 
+          (alpha * fs2 + qs) * (1 - (omega1 / k1))
         
         wm1 <- (x1 * f1) / (m1 + f1 * h1 ^ (-1))
         w.m1 <- wm1 - (wm1 - dm1) * (omega1 / k1)
         c.m1 <- dm1
         
-        d.m1 <- (w.m1 - c.m1 - sm1 - ab) * m1 +
-          (ad * m2 + q) * (1 - (omega1 / k1))
+        d.m1 <- (w.m1 - c.m1 - sm1 - a) * m1 +
+          (alpha * m2 + q) * (1 - (omega1 / k1))
         
-        d.ms1 <- - (c.m1 + ab) * ms1 + sm1 * m1 + 
-          (ad * ms2 + qs) * (1 - (omega1 / k1))
+        d.ms1 <- - (c.m1 + a) * ms1 + sm1 * m1 + 
+          (alpha * ms2 + qs) * (1 - (omega1 / k1))
         
         x2 <- (b2 * (h2 * m2 + f2)) / (2 * h2 * f2 * m2)
         w.f2 <- (m2 * x2) /  (m2 + f2 * h2 ^ (-1))
         c.f2 <- df2 + (w.f2 - df2) * (omega2 / k2)
         
-        d.f2 <- (w.f2 - c.f2 - sf2 - ad) * f2 +
-          ab * f1 * (1 - (omega2 / k2))
+        d.f2 <- (w.f2 - c.f2 - sf2 - alpha) * f2 +
+          a * f1 * (1 - (omega2 / k2))
         
-        d.fs2 <- - (c.f2 + ad) * fs2 + sf2 * f2 +
-          ab * fs1 * (1 - (omega2 / k2))
+        d.fs2 <- - (c.f2 + alpha) * fs2 + sf2 * f2 +
+          a * fs1 * (1 - (omega2 / k2))
         
         w.m2 <- (f2 * x2) / (m2 + f2 * h2 ^ (-1))
         c.m2 <- dm2 + (w.m2 - dm2) * (omega2 / k2)
         
-        d.m2 <- (w.m2 - c.m2 - sm2 - ad) * m2 +
-          ab * m1 * (1 - (omega2 / k2))
+        d.m2 <- (w.m2 - c.m2 - sm2 - alpha) * m2 +
+          a * m1 * (1 - (omega2 / k2))
         
-        d.ms2 <- - (c.m2 + ad) * ms2 + sm2 * m2 +
-          ab * ms1 * (1 - (omega2 / k2))
+        d.ms2 <- - (c.m2 + alpha) * ms2 + sm2 * m2 +
+          a * ms1 * (1 - (omega2 / k2))
         
         d.n1 <- d.f1 + d.m1
         d.ns1 <- d.fs1 + d.ms1
@@ -180,8 +180,8 @@ SolveIASA <- function(pars = NULL, init = NULL, time = NULL, s.range = NULL, ab.
     
     return(as.data.frame(SolveIASA.out))
   } 
-  if (is.null(s.range) & is.null(ab.range) & 
-        is.null(ad.range)) {
+  if (is.null(s.range) & is.null(a.range) & 
+        is.null(alpha.range)) {
     output <- SolveIASAfu(pars = pars, init = init, time = time)
     SolveIASA <- list(
       name = 'SolveIASA',
@@ -193,41 +193,41 @@ SolveIASA <- function(pars = NULL, init = NULL, time = NULL, s.range = NULL, ab.
     class(SolveIASA) <- 'capmModels'
     return(SolveIASA)
   } else {
-    if(length(ab.range) != 2) {
-      stop('The length of ab.range must be equal to 2.')
+    if(length(a.range) != 2) {
+      stop('The length of a.range must be equal to 2.')
     }
-    if(length(ad.range) != 2) {
-      stop('The length of ad.range must be equal to 2.')
+    if(length(alpha.range) != 2) {
+      stop('The length of alpha.range must be equal to 2.')
     }
-    if(length(im.range) != 2) {
-      stop('The length of im.range must be equal to 2.')
+    if(length(v.range) != 2) {
+      stop('The length of v.range must be equal to 2.')
     }
-    if(any(ab.range > 1 | ad.range > 1 | im.range > 1)) {
-      stop('Values in ab.range, ad.range,\nim.range and s.range must be lesser or equal to 1.')
+    if(any(a.range > 1 | alpha.range > 1 | v.range > 1)) {
+      stop('Values in a.range, alpha.range,\nv.range and s.range must be lesser or equal to 1.')
     }
     if(any(s.range > 1)) {
       stop('Values in s.range must be lesser or equal to 1.')
     }
     output <- NULL
     paras <- pars
-    ab.range <- c(ab.range[1], pars['ab'], ab.range[2])
-    ad.range <- c(ad.range[1], pars['ad'], ad.range[2])
-    for (i in 1:length(im.range)) {
-      for (i1 in 1:length(ab.range)) {
-        for (i2 in 1:length(ad.range)) {
+    a.range <- c(a.range[1], pars['a'], a.range[2])
+    alpha.range <- c(alpha.range[1], pars['alpha'], alpha.range[2])
+    for (i in 1:length(v.range)) {
+      for (i1 in 1:length(a.range)) {
+        for (i2 in 1:length(alpha.range)) {
           for (i3 in 1:length(s.range)) {
             if (s.fm) {
               paras[c('sf1', 'sm1', 'sf2', 'sm2',
-                      'ad', 'ab', 'v')] <- 
+                      'alpha', 'a', 'v')] <- 
                 c(s.range[i3], s.range[i3],
                   s.range[i3], s.range[i3],
-                  ad.range[i2], ab.range[i1],
-                  im.range[i])
+                  alpha.range[i2], a.range[i1],
+                  v.range[i])
             } else {
-              paras[c('sf1', 'sf2', 'ad', 'ab', 'v')] <- 
+              paras[c('sf1', 'sf2', 'alpha', 'a', 'v')] <- 
                 c(s.range[i3], s.range[i3],
-                  ad.range[i2], ab.range[i1], 
-                  im.range[i])
+                  alpha.range[i2], a.range[i1], 
+                  v.range[i])
             }
             output <- rbind(
               output,
@@ -246,14 +246,14 @@ SolveIASA <- function(pars = NULL, init = NULL, time = NULL, s.range = NULL, ab.
       N = c(rowSums(output[, 2:5]), rowSums(output[, 6:9])),
       group = rep(1:2, each = nrow(output)),
       s = rep(s.range, each = length(time)),
-      ad = rep(ad.range, 
+      alpha = rep(alpha.range, 
                  each = length(time) * length(s.range)),
-      ab = rep(ab.range, 
+      a = rep(a.range, 
                  each = length(time) * length(s.range) * 
-                   length(ad.range)),
-      im = rep(im.range, 
+                   length(alpha.range)),
+      im = rep(v.range, 
                each = length(time) * length(s.range) * 
-                 length(ad.range) * length(ab.range)))
+                 length(alpha.range) * length(a.range)))
     names(output)[1:5] <- c('t', 'f', 'fs', 'm', 'ms')
     SolveIASA <- list(
       name = 'SolveIASA',
